==> scraping-1.3.21-sources.jar: com/tenqube/visual_scraper/Main2Activity.java <==
package com.tenqube.visual_scraper;

import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import android.webkit.WebView;
import android.widget.Button;
import android.widget.EditText;
import android.widget.FrameLayout;

import com.tenqube.visual_scraper.constants.Constants;

import timber.log.Timber;

public class Main2Activity extends Activity implements MallViewService, ScrapService.OnResultCallback<Void>{

    public static final String API_KEY = "sVPnrNW0Fg4fujRSLJrYn8FJWyO5BtS21hAbOYXc";//"6jLdbwCdun2BzhbCq7yEhak9K80ZcJZWaS8aIKYw";
    private WebView webView;
    FrameLayout frameLayout;
    ScrapService scrapService;
    int i=8;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_main2);
        frameLayout = findViewById(R.id.container);
        Button button = findViewById(R.id.next_btn);
        Button startBtn = findViewById(R.id.start_btn);
        Button loginBtn = findViewById(R.id.login);
        EditText idInput = findViewById(R.id.id_input);
        EditText passwordInput = findViewById(R.id.password_input);

        try {

            scrapService = new ScrapServiceImpl(this, this, API_KEY, Constants.LAYER.DEV, "testUUID", "visual", "test_ad_id");
            button.setOnClickListener(view -> {
                if (i<12) {
                    i++;
                }else if(i == 12) {
                    i=1;
                }
                goParsing(i);

            });

            startBtn.setOnClickListener(view -> {
                goParsing(i);


            });

            loginBtn.setOnClickListener(view -> {
                try {
                    Timber.i("loginBtn"+"id : "+idInput.getText().toString()+"/"+passwordInput.getText().toString());
                    scrapService.startLoginAndParsing(idInput.getText().toString(), passwordInput.getText().toString(), i, this);

                } catch (Exception e) {
                    e.printStackTrace();
                }
            });

        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    private void goParsing(int mallId) {
        try {
            switch (mallId) {
                case 1 :
                    scrapService.startLoginAndParsing( "oyabungz", "tenqube1@", 1, this);
//                    scrapService.insertUserEntity(new UserEntity(1, "oyabungz", "tenqube1@"));
                    break;
                case 2 :
                    scrapService.startLoginAndParsing( "assayaroo2@naver.com", "tenqube1@", 2, this);
//                    scrapService.insertUserEntity(new UserEntity(2, "assayaroo2@naver.com", "tenqube1@"));
                    break;
                case 3 :
                    scrapService.startLoginAndParsing( "oyabongz", "tenqube1@0", 3, this);
//                    scrapService.insertUserEntity(new UserEntity(3, "oyabongz", "tenqube1@"));
                    break;
                case 4 :
                    scrapService.startLoginAndParsing( "freesky111","dlfemd77",4, this);
                    break;
                case 5 :
                    scrapService.startLoginAndParsing( "skj8704@gmail.com","tenqube1@",5, this);
                    break;
                case 6 :
                    scrapService.startLoginAndParsing( "assayaroo2","tenqube1@",6, this); //tilleul92 (비번변경-막힘)
                    break;
                case 7 :
                    scrapService.startLoginAndParsing("freesky111","tenqube1@",7, this);
                    break;
                case 8 :
                    scrapService.startLoginAndParsing("freesky111","10041004a!",8, this);
                    break;
                case 9 :
                    scrapService.startLoginAndParsing("assayaroo2","tenqube1@",9, this);
                    break;
                case 10 :
                    scrapService.startLoginAndParsing("freesky111","tenqube1@",10, this);
                    break;
                case 11 :
                    scrapService.startLoginAndParsing("tilleul92@naver.com","tenqube1@",11, this);
                    break;
                case 12 :
                    scrapService.startLoginAndParsing("ceunsong@gmail.com","tenqube10",12, this);
//                    scrapService.startLoginAndParsing("cide@dreamwiz.com","tenqube10",12, this);

                    break;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    @Override
    public void notifyInProgressStatus(String msg) {

    }

    @Override
    public void onDataLoaded(Void item) {

    }

    @Override
    public void onFail(int mId, Constants.ERROR error, String msg) {
        Timber.i("Activity"+ "error" + error.name() + "onFail" + msg);

    }

    @Override
    public void setWebView(WebView webView, int isVisible) {
        new Handler(Looper.getMainLooper()).post(() -> {
            if (View.VISIBLE == isVisible) {
                frameLayout.removeView(scrapService.getWebView());
                frameLayout.addView(scrapService.getWebView());
            } else {
//                frameLayout.removeView(scrapService.getWebView());
            }
        });

    }

}

==> scraping-1.4.6-sources.jar: com/tenqube/visual_scraper/Main2Activity.java <==
package com.tenqube.visual_scraper;

import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import android.webkit.WebView;
import android.widget.Button;
import android.widget.EditText;
import android.widget.FrameLayout;

import com.tenqube.visual_scraper.constants.Constants;

import timber.log.Timber;

public class Main2Activity extends Activity implements MallViewService, ScrapService.OnResultCallback<Void>{

    public static final String API_KEY = "sVPnrNW0Fg4fujRSLJrYn8FJWyO5BtS21hAbOYXc";//"6jLdbwCdun2BzhbCq7yEhak9K80ZcJZWaS8aIKYw";
    private WebView webView;
    FrameLayout frameLayout;
    ScrapService scrapService;
    int i=8;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_main2);
        frameLayout = findViewById(R.id.container);
        Button button = findViewById(R.id.next_btn);
        Button startBtn = findViewById(R.id.start_btn);
        Button loginBtn = findViewById(R.id.login);
        EditText idInput = findViewById(R.id.id_input);
        EditText passwordInput = findViewById(R.id.password_input);

        try {

            scrapService = new ScrapServiceImpl(this, this, API_KEY, Constants.LAYER.DEV, "testUUID", "visual", "test_ad_id");
            button.setOnClickListener(view -> {
                if (i<12) {
                    i++;
                }else if(i == 12) {
                    i=1;
                }
                goParsing(i);

            });

            startBtn.setOnClickListener(view -> {
                goParsing(i);


            });

            loginBtn.setOnClickListener(view -> {
                try {
                    Timber.i("loginBtn"+"id : "+idInput.getText().toString()+"/"+passwordInput.getText().toString());
                    scrapService.startLoginAndParsing(idInput.getText().toString(), passwordInput.getText().toString(), i, this);

                } catch (Exception e) {
                    e.printStackTrace();
                }
            });

        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    private void goParsing(int mallId) {
        try {
            switch (mallId) {
                case 1 :
                    scrapService.startLoginAndParsing( "aa", "1", 1, this);
//                    scrapService.insertUserEntity(new UserEntity(1, "oyabungz", "tenqube1@"));
                    break;
                case 2 :
                    scrapService.startLoginAndParsing( "aa", "1", 2, this);
//                    scrapService.insertUserEntity(new UserEntity(2, "assayaroo2@naver.com", "tenqube1@"));
                    break;
                case 3 :
                    scrapService.startLoginAndParsing( "aa", "1", 3, this);
//                    scrapService.insertUserEntity(new UserEntity(3, "oyabongz", "tenqube1@"));
                    break;
                case 4 :
                    scrapService.startLoginAndParsing( "aa","1",4, this);
                    break;
                case 5 :
                    scrapService.startLoginAndParsing( "aa","1",5, this);
                    break;
                case 6 :
                    scrapService.startLoginAndParsing( "aa","1",6, this); //tilleul92 (비번변경-막힘)
                    break;
                case 7 :
                    scrapService.startLoginAndParsing("aa","1",7, this);
                    break;
                case 8 :
                    scrapService.startLoginAndParsing("aa","1",8, this);
                    break;
                case 9 :
                    scrapService.startLoginAndParsing("aa","1",9, this);
                    break;
                case 10 :
                    scrapService.startLoginAndParsing("aa","1",10, this);
                    break;
                case 11 :
                    scrapService.startLoginAndParsing("aa","1",11, this);
                    break;
                case 12 :
                    scrapService.startLoginAndParsing("aa","1",12, this);
//                    scrapService.startLoginAndParsing("cide@dreamwiz.com","tenqube10",12, this);

                    break;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    @Override
    public void notifyInProgressStatus(String msg) {

    }

    @Override
    public void onDataLoaded(Void item) {

    }

    @Override
    public void onFail(int mId, Constants.ERROR error, String msg) {
        Timber.i("Activity"+ "error" + error.name() + "onFail" + msg);

    }

    @Override
    public void setWebView(WebView webView, int isVisible) {
        new Handler(Looper.getMainLooper()).post(() -> {
            if (View.VISIBLE == isVisible) {
                frameLayout.removeView(scrapService.getWebView());
                frameLayout.addView(scrapService.getWebView());
            } else {
//                frameLayout.removeView(scrapService.getWebView());
            }
        });

    }

}
